aboutsummaryrefslogtreecommitdiffstats
path: root/boards/base/RaspberryPi/FreeRTOS/uart.c
diff options
context:
space:
mode:
Diffstat (limited to 'boards/base/RaspberryPi/FreeRTOS/uart.c')
-rw-r--r--boards/base/RaspberryPi/FreeRTOS/uart.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/boards/base/RaspberryPi/FreeRTOS/uart.c b/boards/base/RaspberryPi/FreeRTOS/uart.c
index 92f837e7..ef040fca 100644
--- a/boards/base/RaspberryPi/FreeRTOS/uart.c
+++ b/boards/base/RaspberryPi/FreeRTOS/uart.c
@@ -46,12 +46,12 @@ enum {
/*
* delay function
* int32_t delay: number of cycles to delay
*
* This just loops <delay> times in a way that the compiler
* wont optimize away.
*/
-static void delay(int32_t count) {
+static void delay(gI32 count) {
asm volatile("__delay_%=: subs %[count], %[count], #1; bne __delay_%=\n"
: : [count]"r"(count) : "cc");
}
@@ -102,9 +102,9 @@ void uart_init() {
/*
* Transmit a byte via UART0.
* uint8_t Byte: byte to send.
*/
-void uart_putc(uint8_t byte) {
+void uart_putc(gU8 byte) {
// wait for UART to become ready to transmit
while (1) {
if (!(mmio_read(UART0_FR) & (1 << 5))) {
@@ -46,12 +46,12 @@ enum {
/*
* delay function
- * int32_t delay: number of cycles to delay
+ * gI32 delay: number of cycles to delay
*
* This just loops <delay> times in a way that the compiler
@@ -102,9 +102,9 @@ void uart_init() {
/*
* Transmit a byte via UART0.
- * uint8_t Byte: byte to send.
+ * gU8 Byte: byte to send.
*/